@@ -9,11 +9,12 @@ from . state import *
 
 
 __all__ = ('CommandLineClient', 'CommandLineMixin', 'LoggingMixin', 'MqttClient',
-    'Skill', 'SnipsClient', 'SnipsError', 'SnipsClarificationError', 'StateAwareMixin',
+    'Skill', 'SnipsClient', 'SnipsError', 'SnipsClarificationError',
+    'StateAwareMixin', 'ColorFormatter',
     'debug_json', 'get_translations', 'topic', 'min_confidence', 'MultiRoomConfig',
     'on_intent', 'intent', 'PARDON', 'require_slot',
     'on_hotword_detected', 'on_start_session', 'on_session_started',
     'on_end_session', 'on_continue_session', 'on_session_ended', 'on_play_finished',
     'CONFIRMATIONS', 'ROOMS', 'room_with_article', 'room_with_preposition')
 
-__version__ = '0.1.6'
+__version__ = '0.1.7'
