@@ -1,8 +1,8 @@
-from colors import red, green, yellow, blue, magenta, cyan
+from colors import color, cyan, green, magenta, red, white, yellow
 from functools import partial
 import logging, re, sys
 
-__all__ = ('LoggingMixin', )
+__all__ = ('ColorFormatter', 'LoggingMixin', )
 
 
 class LoggingMixin:
@@ -14,8 +14,8 @@ class LoggingMixin:
 
 
     def colored_log(self, level, format, *args, color=str):
-        self.log.log(level, format, *map(self.COLORIZE,
-            map(color, args)))
+        self.log.log(level, format,
+            *map(self.COLORIZE, map(color, args)))
     
 
     def tabular_log(self, level, key, value, label_color=str, width=INDENT):
@@ -40,3 +40,28 @@ class LoggingMixin:
         'Log an action response'
         if response: self.tabular_log(level, 'answer',
             red(response, style='bold'), label_color=green)
+
+
+class ColorFormatter(logging.Formatter):
+    'Color log output by log level'
+    # See: https://stackoverflow.com/a/56944256
+    
+    FORMATS = {}
+
+    
+    def __init__(self, format):
+        if sys.stdout.isatty():
+            self.FORMATS.update({
+                logging.DEBUG:    logging.Formatter(color(format, style='faint')),
+                logging.INFO:     logging.Formatter(white(format)),
+                logging.WARNING:  logging.Formatter(yellow(format)),
+                logging.ERROR:    logging.Formatter(red(format)),
+                logging.CRITICAL: logging.Formatter(
+                    color(format, fg='red', style='bold'))
+            })
+        self.default_formatter = logging.Formatter(format)
+
+
+    def format(self, record):
+        formatter = self.FORMATS.get(record.levelno, self.default_formatter)
+        return formatter.format(record)
