@@ -8,7 +8,7 @@ from argparse import ArgumentParser
 from functools import wraps
 from getpass import getpass
 from paho.mqtt.client import Client as PahoClient, MQTTv311
-import json, logging
+import json, logging, os, sys
 
 
 __all__ = ('MqttClient', 'CommandLineMixin', 'topic', 'CommandLineClient')
@@ -150,9 +150,10 @@ class CommandLineMixin:
         3: logging.DEBUG,
     }
     
-    DEFAULT_LOG_LEVEL = 2
-    LOG_FORMAT = '%(message)s'
-    LOG_FILE = None
+    LOG_LEVEL  = os.environ.get('LOG_LEVEL', 2)
+    LOG_FILE   = os.environ.get('LOG_FILE')
+    LOG_FORMAT = os.environ.get('LOG_FORMAT', '%(asctime)s %(message)s'
+            if sys.stdout.isatty() else '%(message)s')
 
 
     def __init__(self):
@@ -168,7 +169,7 @@ class CommandLineMixin:
     def parse_args(self, args=None):
         self.parser = ArgumentParser(description=self.__doc__)
         self.parser.add_argument('-v', '--verbosity',
-            type=int, choices=[0, 1, 2, 3], default=self.DEFAULT_LOG_LEVEL,
+            type=int, choices=[0, 1, 2, 3], default=self.LOG_LEVEL,
             help='Logging verbosity: 0=errors only, 1=errors and warnings, 2=normal output, 3=debug output')
         self.add_arguments()
         
